@@ -50,6 +50,8 @@ class NetcatsTool(Tool):
     cmdline_options = [
         ('-p', '--port', 'TCP port to connect to',
             dict(dest='port')),
+        ('', '--tag-lines', 'tag output lines with target address',
+            dict(dest='tag_lines', action='store_true')),
         #('-O', '--open', 'print only results for open ports',
         #    dict(dest='open')),
     ]
@@ -146,7 +148,16 @@ class NetcatsTool(Tool):
             if sock in rlist:
                 data = sock.recv(4096)
                 if len(data) > 0:
-                    self._outfile.write(data)
+                    if self.options.tag_lines:
+                        tag = self._host
+                        data = tag + data.replace('\n', '\n' + tag + ':')
+                    while True:
+                        try:
+                            self._outfile.write(data)
+                        except IOError:
+                            pass
+                        else:
+                            break
                     self._outfile.flush()
                     if self.options.split_tee:
                         sys.stdout.write(data)
