@@ -39,8 +39,8 @@ class WebgetTool(Tool):
     ]
 
     @classmethod
-    def print_source(self):
-        print open(__file__).read()
+    def print_source(cls):
+        cls._print_source(__file__)
 
     def __init__(self, *args, **kw):
         super(WebgetTool, self).__init__(*args, **kw)
